@@ -64,6 +64,7 @@ case "della tariffa arrotondato a":  		$messaggio = "of the rate rounded to"; br
 case "considera il costo percentuale come letto(i) aggiuntivo(i)":	$messaggio = "consider this percentage cost as an extra bed(s)"; break;
 case "Procedi nell'inserimento del nuovo costo aggiuntivo":	$messaggio = "Proceed inserting the new extra cost"; break;
 case "Caparra":  				$messaggio = "Deposit"; break;
+case "La caparra normale per":  		$messaggio = "The normal deposit for"; break;
 case "arrotondata a":  				$messaggio = "rounded to"; break;
 case "Inserisci o modifica la caparra":  	$messaggio = "Insert or modify the deposit"; break;
 case "Vedi i prezzi già inseriti":  		$messaggio = "View the prices already inserted"; break;
@@ -236,6 +237,7 @@ case "per settimana":  				$messaggio = "per week"; break;
 case "per giorno":  				$messaggio = "per day"; break;
 case "La caparra è errata":  			$messaggio = "The deposit is wrong"; break;
 case "Commissioni":  				$messaggio = "Commissions"; break;
+case "Le commissioni normali su":  		$messaggio = "The normal commissions on"; break;
 case "Inserisci o modifica le commissioni":  	$messaggio = "Insert or modify commissions"; break;
 case "Tasse":  					$messaggio = "Taxes"; break;
 case "Tasse applicate su":  			$messaggio = "Taxes applied on"; break;
@@ -324,8 +326,11 @@ case "Mostrare come tipo di persona":  		$messaggio = "Display as person type";
 case "Applicare la percentuale del tipo di persona al prezzo del costo":	$messaggio = "Apply the percentage of the person type to the price of the cost"; break;
 case "Neonati (0-23 mesi)":  			$messaggio = "Infants (0-23 months)"; break;
 case "tariffe con":  				$messaggio = "rates with"; break;
-case "La caparra normale per":  		$messaggio = "The normal deposit for"; break;
-case "Le commissioni normali su":  		$messaggio = "The normal commissions on"; break;
+case "per persona nullo":  			$messaggio = "per person zero"; break;
+case "fisso nullo":  				$messaggio = "fixed zero"; break;
+case "da per persona":  			$messaggio = "from per person"; break;
+case "più fisso":  				$messaggio = "from fixed"; break;
+case "dal fisso":  				$messaggio = "plus fixed"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
