@@ -4,25 +4,6 @@ switch ($messaggio) {
 
 case "a":  					$messaggio = "to"; break;
 case "al":  					$messaggio = "to"; break;
-case " Do":  					$messaggio = " Su"; break;
-case " Lu":  					$messaggio = " Mo"; break;
-case " Ma":  					$messaggio = " Tu"; break;
-case " Me":  					$messaggio = " We"; break;
-case " Gi":  					$messaggio = " Th"; break;
-case " Ve":  					$messaggio = " Fr"; break;
-case " Sa":  					$messaggio = " Sa"; break;
-case "Gen":  					$messaggio = "Jan"; break;
-case "Feb":  					$messaggio = "Feb"; break;
-case "Mar":  					$messaggio = "Mar"; break;
-case "Apr":  					$messaggio = "Apr"; break;
-case "Mag":  					$messaggio = "May"; break;
-case "Giu":  					$messaggio = "Jun"; break;
-case "Lug":  					$messaggio = "Jul"; break;
-case "Ago":  					$messaggio = "Aug"; break;
-case "Set":  					$messaggio = "Sep"; break;
-case "Ott":  					$messaggio = "Oct"; break;
-case "Nov":  					$messaggio = "Nov"; break;
-case "Dic":  					$messaggio = "Dec"; break;
 case "aggiungi":  				$messaggio = "add"; break;
 case "SI":  					$messaggio = "YES"; break;
 case "NO":  					$messaggio = "NO"; break;
